jQuery(document).ready(function($) {
    function displayOpenGraphData(data, url) {
        var ogdDataDiv = $('#ogd-data');
        ogdDataDiv.empty();

        if (data['og:image'] || data['og:title'] || data['og:description']) {
            var previewDiv = $('<div>', { id: 'ogd-preview' });
            if (data['og:image']) {
                var img = $('<img>', { src: data['og:image'] });
                previewDiv.append(img);
            }
            var previewContentDiv = $('<div>', { id: 'ogd-preview-content' });
            if (data['og:title']) {
                var previewTitle = $('<h3>', { id: 'ogd-preview-title', text: data['og:title'] });
                previewContentDiv.append(previewTitle);
            }
            if (data['og:description']) {
                var previewDescription = $('<p>', { id: 'ogd-preview-description', text: data['og:description'] });
                previewContentDiv.append(previewDescription);
            }
            previewDiv.append(previewContentDiv);
            ogdDataDiv.append(previewDiv);
        }

        if (Object.keys(data).length > 0) {
            var title = $('<h2>', { id: 'ogd-title', text: 'Open Graph Data' });
            ogdDataDiv.append(title);

            var hr = $('<hr>');
            ogdDataDiv.append(hr);
        }

        for (var property in data) {
            if (data.hasOwnProperty(property) && property !== 'og:image:secure_url') {
                var p = $('<p>').html('<strong>' + property + ':</strong> ' + data[property]);
                ogdDataDiv.append(p);
            }
        }

        var refreshButton = $('<button>', {
            text: 'Refresh Data',
            id: 'ogd-refresh-button',
            'data-url': url
        });
        ogdDataDiv.append(refreshButton);

        refreshButton.on('click', function() {
            fetchOpenGraphData(url);
        });
    }

    function fetchOpenGraphData(url) {
        $.ajax({
            url: ogd_ajax_object.ajax_url,
            method: 'GET',
            data: {
                action: 'ogd_fetch_data',
                url: url
            },
            success: function(response) {
                if (response.success) {
                    displayOpenGraphData(response.data, url);
                } else {
                    $('#ogd-data').html('<p>' + response.data + '</p>');
                }
            }
        });
    }

    $('#ogd-fetch-button').on('click', function() {
        var url = $('#ogd-url').val();
        fetchOpenGraphData(url);
    });
});
