<?php
/*
Plugin Name: Open Graph Debugger
Description: Fetches and displays Open Graph data from a URL and provides a refresh button.
Version: 1.4
Author: SB
*/

// Enqueue the styles and scripts
function ogd_enqueue_scripts() {
    wp_enqueue_style('ogd-style', plugin_dir_url(__FILE__) . 'css/style.css');
    wp_enqueue_script('ogd-script', plugin_dir_url(__FILE__) . 'js/script.js', array('jquery'), null, true);
    wp_localize_script('ogd-script', 'ogd_ajax_object', array('ajax_url' => admin_url('admin-ajax.php')));
}
add_action('wp_enqueue_scripts', 'ogd_enqueue_scripts');

// Function to fetch Open Graph data
function ogd_fetch_open_graph_data($url) {
    $response = wp_remote_get($url);

    if (is_wp_error($response)) {
        return ['error' => 'Unable to retrieve data.'];
    }

    $html = wp_remote_retrieve_body($response);

    if (!$html) {
        return ['error' => 'No data found.'];
    }

    $doc = new DOMDocument();
    @$doc->loadHTML($html);

    $xpath = new DOMXPath($doc);
    $meta_tags = $xpath->query('//meta[starts-with(@property, "og:") or starts-with(@name, "twitter:") or starts-with(@property, "fb:")]');

    $og_data = [];
    foreach ($meta_tags as $tag) {
        $property = $tag->getAttribute('property') ?: $tag->getAttribute('name');
        $content = $tag->getAttribute('content');
        $og_data[$property] = $content;
    }

    return $og_data;
}

// Shortcode function to display the input field, button, and Open Graph data
function ogd_display_open_graph_data() {
    ob_start();
    ?>
    <div id="ogd-container">
        <div id="ogd-description">
            <h2>Open Graph Debugger</h2>
            <p>This tool allows you to fetch and display Open Graph data from any URL. Simply enter the URL and click the "Fetch Data" button. Note that the data is fetched in real-time and is not stored anywhere.<br>
            I have included a button at the bottom to refetch the data if you make changes to the URL.</p>
        </div>
        <div id="ogd-input-container">
            <input type="text" id="ogd-url" placeholder="Enter URL" />
            <button id="ogd-fetch-button">Fetch Data</button>
        </div>
        <div id="ogd-data"></div>
        <div id="ogd-footer">
            <p>Created by: <img src="https://wpscriptly.com/wp-content/uploads/2024/05/wpsc-logo-256.png" alt="WpScriptly" style="width: 16px; vertical-align: middle;"><a href="https://wpscriptly.com" target="_blank"> WpScriptly</a></p>
        </div>
    </div>
    <?php
    return ob_get_clean();
}
add_shortcode('ogd_display', 'ogd_display_open_graph_data');

// AJAX handler function to fetch Open Graph data
function ogd_fetch_data() {
    if (!isset($_GET['url'])) {
        wp_send_json_error('No URL provided.');
    }

    $url = esc_url_raw($_GET['url']);
    $og_data = ogd_fetch_open_graph_data($url);

    if (isset($og_data['error'])) {
        wp_send_json_error($og_data['error']);
    }

    wp_send_json_success($og_data);
}
add_action('wp_ajax_ogd_fetch_data', 'ogd_fetch_data');
add_action('wp_ajax_nopriv_ogd_fetch_data', 'ogd_fetch_data');
